<template>
  <div class="CameraManage">
    <div class="cluster">
      <div class="title">集群选择</div>
      <el-select v-model="cluster" placeholder="请选择" @change="selectCluster">
        <el-option
          v-for="item in clusterArr"
          :key="item.value"
          :label="item.label"
          :value="item.value"
        >
        </el-option>
      </el-select>
    </div>
    <div class="content">
      <CameraLeft :appName="'Camera'" ref="left"></CameraLeft>
      <div class="right">
        <div class="tabs">
          <div
            class="tab"
            :class="{ active: activeTab === '信息维护' }"
            @click="handleClick('信息维护')"
          >
            信息维护
          </div>
          <div
            class="tab"
            :class="{ active: activeTab === '场景配置' }"
            @click="handleClick('场景配置')"
          >
            场景配置
          </div>
        </div>

        <CameraInfo
          ref="cameraInfo"
          v-show="activeTab === '信息维护'"
        ></CameraInfo>
        <CameraRules
          v-show="activeTab === '场景配置'"
          ref="sepRule"
        ></CameraRules>
      </div>
    </div>
  </div>
</template>

<script>
import CameraLeft from "@/components/CameraLeft";
import CameraInfo from "./CameraInfo";
import CameraRules from "./CameraRules";
import VideoRuleData from "@/Pool/VideoRuleData";

import { getClusterDevList } from "@/api/clusterManage";

import bus from "@/plugin/bus";
export default {
  components: {
    CameraLeft,
    CameraInfo,
    CameraRules,
  },

  data() {
    return {
      activeTab: "信息维护",
      clusterArr: [],
      cluster: "",
      clusterData: [],
      intervalTimer: null,
      leftWith: 0,
      screenHeight: 0,
    };
  },

  destroyed() {
    this.TreeDataPool.readonly = true;
  },

  watch: {
    "TreeDataPool.activeNode": function (node) {
      sessionStorage.setItem("cameraDevId", node.devId);
      if (this.activeTab == "信息维护") {
        if (this.TreeDataPool.treeActiveName == "camera") {
          this.$refs.cameraInfo.selectCamera(node);
        }
      } else if (this.activeTab === "场景配置") {
        this.$refs.sepRule.initCameraData(node.id);
        if (!this.TreeDataPool.multiple) {
          this.$refs.sepRule.showRules(node.id);
        }
      }
    },
    "TreeDataPool.selectedNodes": {
      handler(nodes, oldVal) {
        if (this.activeTab == "场景配置") {
          //  this.$refs.sepRule.initCameraData(nodes[nodes.length - 1]);
          let CameraArr = [];
          let CameraIds = [];

          nodes.forEach((id) => {
            let newCamera = new VideoRuleData(id);
            CameraArr.push(newCamera);
            CameraIds.push(id);
          });

          this.$refs.sepRule.Carmeras = CameraArr;
          if (
            nodes.length == 1 &&
            oldVal.length == 1 &&
            nodes[0] == oldVal[0]
          ) {
            return;
          }
          if (this.TreeDataPool.multiple && oldVal[0]) {
            this.$refs.sepRule.showRules(CameraIds);
          }

          console.log(CameraArr);
        }
      },
      deep: true,
    },
    "DataStackPool.selectedDir": {
      handler(node, oldNode) {
        if (this.TreeDataPool.treeActiveName !== "dataStack") {
          return;
        }
        this.$nextTick(() => {
          if (this.activeTab == "信息维护") {
            //   this.$refs.dataStackInfo.selectDir(node);
          } else if (this.activeTab == "场景配置" && node.length !== 0) {
            this.$refs.sepRule.initCameraData(node.id);
          }
        });
      },
      deep: true,
    },
  },
  created() {
    this.getCluster();
    this.TreeDataPool.readonly = false;

    //  this.TreeDataPool.readonly = true;
    //this.TreeDataPool.gbReadonly = true;
    this.TreeDataPool.multiple = false;
    this.TreeDataPool.selectedNode = "";
    this.selectedNodes = [];
  },
  beforeDestroy() {
    sessionStorage.removeItem("devId");
    sessionStorage.removeItem("clusterId");
    clearInterval(this.intervalTimer);
    //this.TreeDataPool.treeActiveName = "camera";
  },
  mounted() {
    this.$nextTick(() => {
      bus.$on("addCameraOnTree", (node) => {
        this.handAddDevice(node);
      });
      bus.$on("addDirOnTree", (node) => {
        this.handAddDIr(node);
      });
      this.TreeDataPool.clean();
    });
  },
  methods: {
    handAddDevice(node) {
      let _this = this;
      setTimeout(() => {
        _this.$refs.cameraInfo.addDevice(node);
        _this.activeTab = "信息维护";
      }, 100);
    },
    handAddDIr(node) {
      let _this = this;
      setTimeout(() => {
        _this.$refs.dataStackInfo.addDir(node);
        _this.activeTab = "信息维护";
      }, 100);
    },
    handleClick(tab) {
      //这个控制是否多选
      //    this.TreeDataPool.multiple = tab.name === "场景配置";
      this.activeTab = tab;
      if (tab === "信息维护") {
        if (this.TreeDataPool.treeActiveName == "camera") {
          this.$refs.cameraInfo.selectCamera(this.TreeDataPool.selectedNode);
        } else if (this.TreeDataPool.treeActiveName == "dataStack") {
          this.$refs.dataStackInfo.selectDir(this.DataStackPool.selectedDir);
        }
      } else if (tab === "场景配置") {
        if (this.TreeDataPool.treeActiveName == "camera") {
          this.$refs.sepRule.initCameraData(this.TreeDataPool.selectedNode.id);
          this.$refs.sepRule.showRules(this.TreeDataPool.selectedNode.id);
        } else if (this.TreeDataPool.treeActiveName == "dataStack") {
          this.$refs.sepRule.initCameraData(this.DataStackPool.selectedDir.id);
        }
      }
    },
    async getCluster() {
      const res = await getClusterDevList();
      if (res && res.success) {
        this.clusterData = res.data.clusterList;
        if (res.data.clusterList <= 0 && res.data.devList <= 0) {
          this.$confirm(
            "系统检测到您还未添加设备, 请在设备管理页面维护",
            "提示",
            {
              confirmButtonText: "跳转",
              cancelButtonText: "取消",
              type: "warning",
            }
          )
            .then(() => {
              this.$router.push("/manageCenter");
            })
            .catch(() => {});
        }

        res.data.clusterList.forEach((item) => {
          this.clusterArr.push({
            label: item.cluster_name,
            value: "0$$" + item.cluster_id,
          });
        });

        res.data.devList.forEach((item) => {
          this.clusterArr.push({
            label: item.devName,
            value: "1$$" + item.devId,
          });
        });

        this.cluster = this.clusterArr[0].value;
        this.selectCluster(this.clusterArr[0].value);
      }
    },
    selectCluster(val) {
      const arr = val.split("$$");
      if (arr[0] == "0") {
        sessionStorage.setItem("clusterId", arr[1]);
        sessionStorage.setItem("devId", "");
        console.log(this.clusterData);
        this.clusterData.forEach((item) => {
          if (arr[1] == item.cluster_id) {
            sessionStorage.setItem("nodeId", item.nodeList[0].devId);
          }
        });
      }
      if (arr[0] == "1") {
        sessionStorage.setItem("clusterId", "");
        sessionStorage.setItem("devId", arr[1]);
        sessionStorage.setItem("nodeId", arr[1]);
      }
      this.TreeDataPool.fetchTreeData();
      this.PollData.statisticTaskInfo();
      this.VideoManageData.init();
      this.PollData.statistics();
    },
  },
};
</script>

<style lang="scss" scoped>
.CameraManage {
  .cluster {
    display: flex;
    align-items: center;
    box-sizing: border-box;
    margin-bottom: 24px;
    padding: 10px;
    height: 72px;
    background-color: #fff;

    .title {
      box-sizing: border-box;
      padding-left: 10px;
      margin-right: 40px;
      height: 22px;
      font-size: 16px;
      font-weight: 700;
      border-left: 4px solid #0065ff;
    }

    .el-select {
      width: 272px;
      height: 32px;
      line-height: 32px;

      ::v-deep input:focus {
        border-color: #0065ff;
      }

      ::v-deep .el-input.is-focus .el-input__inner {
        border-color: #0065ff;
      }

      ::v-deep input {
        border-radius: 0;
        height: 32px;
      }

      ::v-deep .el-icon-arrow-up {
        line-height: 32px;
      }
    }
  }

  .content {
    box-sizing: border-box;
    margin-bottom: 60px;
    display: flex;
    align-items: stretch;
    .CameraLeft {
      margin-right: 24px;
      width: 292px;
    }

    .right {
      flex: 1;

      .tabs {
        display: flex;
        margin-bottom: 24px;
        height: 42px;
        background-color: #fff;

        .tab {
          width: 104px;
          height: 42px;
          text-align: center;
          line-height: 42px;
          border-bottom: 2px solid #fff;
          color: #666;
          cursor: pointer;

          &.active {
            color: #0065ff;
            border-color: #0065ff;
          }
        }
      }
    }
  }
}
</style>